@@ -117,6 +117,7 @@ enum {
     SYSTEMD_SLEEP_PREFIX_OPTION,
     SYSTEMD_SYSCONF_PREFIX_OPTION,
     GBM_BACKEND_DIR_OPTION,
+    GBM_BACKEND_DIR32_OPTION,
     ALLOW_INSTALLATION_WITH_RUNNING_DRIVER_OPTION,
     REBUILD_INITRAMFS_OPTION,
     PRINT_RECOMMENDED_MODULE_TYPE_OPTION,
@@ -309,11 +310,19 @@ static const NVGetoptOption __options[] = {
     { "gbm-backend-dir", GBM_BACKEND_DIR_OPTION, NVGETOPT_STRING_ARGUMENT, NULL,
       "The path relative to the OpenGL library installation prefix under "
       "which the NVIDIA GBM backend library will be installed.  The "
-      "default is '$libdir/gbm', where '$libdir' is '" DEFAULT_64BIT_LIBDIR
+      "default is '<libdir>/gbm', where '<libdir>' is '" DEFAULT_64BIT_LIBDIR
       "' or '" DEFAULT_LIBDIR "', depending on the installed Linux "
       "distribution.  Only under very rare circumstances should this option be "
       "used." },
 
+    { "gbm-backend-dir32", GBM_BACKEND_DIR32_OPTION, NVGETOPT_STRING_ARGUMENT, NULL,
+      "The path relative to the 32-bit OpenGL library installation prefix under "
+      "which the 32-bit NVIDIA GBM backend library will be installed.  The "
+      "default is '<libdir>/gbm', where <libdir>' is '" DEFAULT_LIBDIR
+      "' or '" DEFAULT_32BIT_LIBDIR "', depending on the installed Linux "
+      "distribution.  Only under very rare circumstances should this option be "
+      "used." },
+
     { "documentation-prefix", DOCUMENTATION_PREFIX_OPTION,
       NVGETOPT_STRING_ARGUMENT,  NULL,
       "The prefix under which the documentation files for the NVIDIA "
@@ -716,11 +725,18 @@ static const NVGetoptOption __options[] = {
       "install these symlinks, or '/etc/systemd/system' if pkg-config is not "
       "available. Ignored if --no-systemd is specified." },
 
+    { "kernel-module-type", 'M',
+      NVGETOPT_STRING_ARGUMENT, NULL,
+      "The type of kernel modules to build and install. Valid values are "
+      "\"open\" and \"proprietary\"."
+    },
+
     { "kernel-module-build-directory", 'm',
       NVGETOPT_STRING_ARGUMENT, NULL,
-      "The path within the driver package that contains the kernel module "
-      "build files is normally 'kernel/'.  This option can be used to "
-      "override this value." },
+      "Directly set the directory within the package from which to build the "
+      "kernel modules. This option is deprecated; use \"--kernel-module-type\" "
+      "instead."
+    },
 
     { "print-recommended-kernel-module-type",
       PRINT_RECOMMENDED_MODULE_TYPE_OPTION,  0, NULL,
